# kweb 0.0.9

KLayout Web Viewer ![demo](https://i.imgur.com/HPvePvX.png)

Based on https://github.com/klayoutmatthias/canvas2canvas

## Run

Go to src/kweb and run
`uvicorn main:app --reload`

Go to http://127.0.0.1:8000/gds/wg to open the waveguide example
